@@ -31,8 +31,10 @@ pub use {koto_bytecode as bytecode, koto_parser as parser, koto_runtime as runti
 use {
     dunce::canonicalize,
     koto_bytecode::{Chunk, LoaderError},
-    koto_runtime::{KotoFile, Loader, MetaKey, RuntimeError, Value, ValueMap, Vm, VmSettings},
-    std::{error::Error, fmt, path::PathBuf, sync::Arc},
+    koto_runtime::{
+        CallArgs, KotoFile, Loader, MetaKey, RuntimeError, Value, ValueMap, Vm, VmSettings,
+    },
+    std::{error::Error, fmt, path::PathBuf, rc::Rc},
 };
 
 #[derive(Debug)]
@@ -89,9 +91,9 @@ pub struct KotoSettings {
     pub run_tests: bool,
     pub run_import_tests: bool,
     pub repl_mode: bool,
-    pub stdin: Arc<dyn KotoFile>,
-    pub stdout: Arc<dyn KotoFile>,
-    pub stderr: Arc<dyn KotoFile>,
+    pub stdin: Rc<dyn KotoFile>,
+    pub stdout: Rc<dyn KotoFile>,
+    pub stderr: Rc<dyn KotoFile>,
 }
 
 impl Default for KotoSettings {
@@ -116,7 +118,7 @@ pub struct Koto {
     pub settings: KotoSettings, // TODO make private, needs enable / disable tests methods
     script_path: Option<PathBuf>,
     loader: Loader,
-    chunk: Option<Arc<Chunk>>,
+    chunk: Option<Rc<Chunk>>,
 }
 
 impl Default for Koto {
@@ -145,7 +147,7 @@ impl Koto {
         }
     }
 
-    pub fn compile(&mut self, script: &str) -> Result<Arc<Chunk>, KotoError> {
+    pub fn compile(&mut self, script: &str) -> Result<Rc<Chunk>, KotoError> {
         let compile_result = if self.settings.repl_mode {
             self.loader.compile_repl(script)
         } else {
@@ -174,7 +176,7 @@ impl Koto {
         }
     }
 
-    pub fn run_chunk(&mut self, chunk: Arc<Chunk>) -> KotoResult {
+    pub fn run_chunk(&mut self, chunk: Rc<Chunk>) -> KotoResult {
         let result = self.runtime.run(chunk)?;
 
         if self.settings.repl_mode {
@@ -200,7 +202,9 @@ impl Koto {
             }
 
             if let Some(main) = self.runtime.get_exported_function("main") {
-                self.runtime.run_function(main, &[]).map_err(|e| e.into())
+                self.runtime
+                    .run_function(main, CallArgs::None)
+                    .map_err(|e| e.into())
             } else {
                 Ok(result)
             }
@@ -277,14 +281,14 @@ impl Koto {
         }
     }
 
-    pub fn call_function_by_name(&mut self, function_name: &str, args: &[Value]) -> KotoResult {
+    pub fn run_function_by_name(&mut self, function_name: &str, args: CallArgs) -> KotoResult {
         match self.runtime.get_exported_function(function_name) {
-            Some(f) => self.call_function(f, args),
+            Some(f) => self.run_function(f, args),
             None => Err(KotoError::FunctionNotFound(function_name.into())),
         }
     }
 
-    pub fn call_function(&mut self, function: Value, args: &[Value]) -> KotoResult {
+    pub fn run_function(&mut self, function: Value, args: CallArgs) -> KotoResult {
         self.runtime
             .run_function(function, args)
             .map_err(|e| e.into())
